#
# spec file for package kubeconform
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider_prefix github.com/yannh/kubeconform
%global import_path     %{provider_prefix}

Name:           kubeconform
Version:        0.6.1
Release:        1.3
Summary:        A fast Kubernetes manifests validator, with support for custom resources
License:        Apache-2.0
URL:            https://github.com/yannh/kubeconform/
Source0:        https://github.com/yannh/kubeconform/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.17

%description
Kubeconform is a Kubernetes manifests validation tool. It is inspired by, contains
code from and is designed to stay close to Kubeval, but with the following
improvements:

- high performance: will validate & download manifests over multiple routines, caching
  downloaded files in memory
- configurable list of remote, or local schemas locations, enabling validating Kubernetes
  custom resources (CRDs) and offline validation capabilities
- uses by default a self-updating fork of the schemas registry maintained by the
  kubernetes-json-schema project - which guarantees up-to-date schemas for all recent versions
  of Kubernetes.

%prep
%autosetup -a1

%build
go build -buildmode=pie -mod=vendor -o bin/ .../.

%install
install -D -m 0755 ./bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%{_bindir}/%{name}
%license LICENSE
%doc Readme.md

%changelog
* Mon Mar 27 2023 andrea.manzini@suse.com
- Update to version 0.6.1:
  * fix: expose error instance path instead of schema path
  * support disabling ssl validation in openapi2jsonschema.py
  * Try to expose JSON paths
  * feat: support to set an alternative image owner
  * Documenting Helm support via 3rd party repo
  * Update LICENSE
  * Add opencontainers label
  * Add informations how to use Kubeconform in Gitlab-CI
* Mon Dec 12 2022 rombert@apache.org
- Update to version 0.5.0:
  * Allow to skip resources using the GVK notation (#92)
  * Update goreleaser (#137)
  * Do not expose internal CPU profiling option as flag (#136)
  * Validate JUnit output against Jenkins JUnit XSD (#134)
  * Add debug information to help understand failures finding schemas (#133)
  * Update fixture file to use no hash function
  * Upgrade hash to sha256. (#126)
  * remove link to dead project (#125)
  * add {{ .Group }} variable to schema location options (#120)
  * Forbid duplicate keys in strict mode (#121)
  * fix: change flag parse error handling to return errors instead of exiting (#107)
  * Adds info about installation via built in Go package manger (#116)
  * Fix grammar in  README.md (#114)
  * add constructor to handle equal sign (=) (#104)
  * chore: print the url of failed download (#96)
  * remove accidentally commited binary
  * Improve handling of cmdline errors (#91)
  * Minor css updates
  * Update website
  * Add cname to website
  * Publish site
  * Fixes acceptance test with new TAP output
  * feat(output/tap): Output qualified resource name
  * add horizontal line
  * set hero image width
  * scripts: Add tests for options
  * scripts: Optionally disallow additionalProperties at the root
  * Update Readme.md
  * Move version to main package
  * Update README
  * Add -v to output version number
  * Fix broken release notes
* Tue Oct 19 2021 Robert Munteanu <rombert@apache.org>
- Initial package
